<?php

/**
 * @file
 * Contains \Drupal\skype\Plugin\field\formatter\SkypeButtonFormatter.
 */

namespace Drupal\skype\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Plugin implementation of the 'skype_button' formatter.
 *
 * @FieldFormatter(
 *   id = "skype_button",
 *   label = @Translation("Skype Button"),
 *   field_types = {
 *     "skype"
 *   }
 * )
 */
class SkypeButtonFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return array(
      'actions' => array('call', 'chat'),
      'image_color' => 'blue',
      'image_size' => 32,
        ) + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $elements['actions'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Choose what you\'d like your button to do:'),
      '#options' => array(
        'call' => t('Call'),
        'chat' => t('Chat'),
      ),
      '#default_value' => $this->getSetting('actions'),
      '#required' => TRUE,
    );

    $elements['image_color'] = array(
      '#type' => 'select',
      '#title' => t('Choose how you want your button to look:'),
      '#options' => array(
        'blue' => t('Blue'),
        'white' => t('White'),
      ),
      '#default_value' => $this->getSetting('image_color'),
      '#required' => TRUE,
    );

    $elements['image_size'] = array(
      '#type' => 'select',
      '#title' => t('Choose the size of your button:'),
      '#options' => array(
        10 => '10px',
        12 => '12px',
        14 => '14px',
        16 => '16px',
        24 => '24px',
        32 => '32px',
      ),
      '#default_value' => $this->getSetting('image_size'),
      '#required' => TRUE,
    );

    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = array();
    $settings = $this->getSettings();

    $actions = array_filter($settings['actions']);
    $summary[] = t('Button action(s): @actions',
        array('@actions' => implode(', ', $actions)));
    $summary[] = t('Button color: @color',
        array('@color' => $settings['image_color']));
    $summary[] = t('Button size: @sizepx',
        array('@size' => $settings['image_size']));

    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = array();
    $settings = $this->getSettings();

    foreach ($items as $delta => $item) {
      // Render each element as skype button.
      $element[$delta] = array(
        '#theme' => 'skype_button',
        '#skype_id' => $item->value,
        '#settings' => $settings,
        '#langcode' => $item->getLangcode(),
        '#attached' => array(
          'library' => array(
            'skype/skype-button'
          ),
        ),
      );
    }

    return $element;
  }

}
